@@ -1,20 +1,10 @@
-/*************************************************************************
- *  Copyright (C) 2008 by Volker Lanz <vl@fidra.de>                      *
- *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2010 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2014-2020 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2015 Teo Mrnjavac <teo@kde.org>
+
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "core/operationrunner.h"
 #include "core/operationstack.h"
@@ -69,7 +59,7 @@ void OperationRunner::run()
         Operation* op = operationStack().operations()[i];
         op->setStatus(Operation::StatusRunning);
 
-        emit opStarted(i + 1, op);
+        Q_EMIT opStarted(i + 1, op);
 
         connect(op, &Operation::progress, this, &OperationRunner::progressSub);
 
@@ -78,18 +68,18 @@ void OperationRunner::run()
 
         disconnect(op, &Operation::progress, this, &OperationRunner::progressSub);
 
-        emit opFinished(i + 1, op);
+        Q_EMIT opFinished(i + 1, op);
     }
 
     if (automounter)
         kdedInterface.call( QStringLiteral("loadModule"), automounterService );
 
     if (!status)
-        emit error();
+        Q_EMIT error();
     else if (isCancelling())
-        emit cancelled();
+        Q_EMIT cancelled();
     else
-        emit finished();
+        Q_EMIT finished();
 }
 
 /** @return the number of Operations to run */
