@@ -1,20 +1,11 @@
-/*************************************************************************
- *  Copyright (C) 2008 by Volker Lanz <vl@fidra.de>                      *
- *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2010 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2012-2019 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2015 Teo Mrnjavac <teo@kde.org>
+    SPDX-FileCopyrightText: 2020 Gaël PORTAY <gael.portay@collabora.com>
+
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
 #include "ops/newoperation.h"
 
@@ -24,6 +15,9 @@
 
 #include "jobs/createpartitionjob.h"
 #include "jobs/createfilesystemjob.h"
+#include "jobs/setpartitionlabeljob.h"
+#include "jobs/setpartitionuuidjob.h"
+#include "jobs/setpartitionattributesjob.h"
 #include "jobs/setfilesystemlabeljob.h"
 #include "jobs/setpartflagsjob.h"
 #include "jobs/checkfilesystemjob.h"
@@ -46,6 +40,9 @@ NewOperation::NewOperation(Device& d, Partition* p) :
     m_TargetDevice(d),
     m_NewPartition(p),
     m_CreatePartitionJob(new CreatePartitionJob(targetDevice(), newPartition())),
+    m_SetPartitionLabelJob(nullptr),
+    m_SetPartitionUUIDJob(nullptr),
+    m_SetPartitionAttributesJob(nullptr),
     m_CreateFileSystemJob(nullptr),
     m_SetPartFlagsJob(nullptr),
     m_SetFileSystemLabelJob(nullptr),
@@ -53,6 +50,21 @@ NewOperation::NewOperation(Device& d, Partition* p) :
 {
     addJob(createPartitionJob());
 
+    if (!p->label().isEmpty()) {
+        m_SetPartitionLabelJob = new SetPartitionLabelJob(targetDevice(), newPartition(), p->label());
+        addJob(setPartitionLabelJob());
+    }
+
+    if (!p->uuid().isEmpty()) {
+        m_SetPartitionUUIDJob = new SetPartitionUUIDJob(targetDevice(), newPartition(), p->uuid());
+        addJob(setPartitionUUIDJob());
+    }
+
+    if (p->attributes()) {
+        m_SetPartitionAttributesJob = new SetPartitionAttributesJob(targetDevice(), newPartition(), p->attributes());
+        addJob(setPartitionAttributesJob());
+    }
+
     const FileSystem& fs = newPartition().fileSystem();
 
     if (fs.type() != FileSystem::Type::Extended) {
