@@ -1,23 +1,14 @@
-/*************************************************************************
- *  Copyright (C) 2008 by Volker Lanz <vl@fidra.de>                      *
- *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
- *                                                                       *
- *  This program is free software; you can redistribute it and/or        *
- *  modify it under the terms of the GNU General Public License as       *
- *  published by the Free Software Foundation; either version 3 of       *
- *  the License, or (at your option) any later version.                  *
- *                                                                       *
- *  This program is distributed in the hope that it will be useful,      *
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of       *
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
- *  GNU General Public License for more details.                         *
- *                                                                       *
- *  You should have received a copy of the GNU General Public License    *
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
- *************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2010 Volker Lanz <vl@fidra.de>
+    SPDX-FileCopyrightText: 2012-2016 Andrius Štikonas <andrius@stikonas.eu>
+    SPDX-FileCopyrightText: 2015 Chris Campbell <c.j.campbell@ed.ac.uk>
+    SPDX-FileCopyrightText: 2015 Teo Mrnjavac <teo@kde.org>
+    SPDX-FileCopyrightText: 2020 Gaël PORTAY <gael.portay@collabora.com>
 
-#if !defined(KPMCORE_NEWOPERATION_H)
+    SPDX-License-Identifier: GPL-3.0-or-later
+*/
 
+#ifndef KPMCORE_NEWOPERATION_H
 #define KPMCORE_NEWOPERATION_H
 
 #include "fs/filesystem.h"
@@ -30,6 +21,9 @@ class Device;
 class OperationStack;
 
 class CreatePartitionJob;
+class SetPartitionLabelJob;
+class SetPartitionUUIDJob;
+class SetPartitionAttributesJob;
 class CreateFileSystemJob;
 class SetFileSystemLabelJob;
 class SetPartFlagsJob;
@@ -83,6 +77,15 @@ protected:
     CreatePartitionJob* createPartitionJob() {
         return m_CreatePartitionJob;
     }
+    SetPartitionLabelJob* setPartitionLabelJob() {
+        return m_SetPartitionLabelJob;
+    }
+    SetPartitionUUIDJob* setPartitionUUIDJob() {
+        return m_SetPartitionUUIDJob;
+    }
+    SetPartitionAttributesJob* setPartitionAttributesJob() {
+        return m_SetPartitionAttributesJob;
+    }
     CreateFileSystemJob* createFileSystemJob() {
         return m_CreateFileSystemJob;
     }
@@ -100,6 +103,9 @@ private:
     Device& m_TargetDevice;
     Partition* m_NewPartition;
     CreatePartitionJob* m_CreatePartitionJob;
+    SetPartitionLabelJob* m_SetPartitionLabelJob;
+    SetPartitionUUIDJob* m_SetPartitionUUIDJob;
+    SetPartitionAttributesJob* m_SetPartitionAttributesJob;
     CreateFileSystemJob* m_CreateFileSystemJob;
     SetPartFlagsJob* m_SetPartFlagsJob;
     SetFileSystemLabelJob* m_SetFileSystemLabelJob;
